import argparse
import asyncio

from functools import partial

from i3ipc import Event
from i3ipc.aio import Connection


def is_floating(container) -> bool:
    if container.floating:
        # We're on i3: on sway it would be None
        # May be 'auto_on' or 'user_on'
        return "_on" in container.floating
    else:
        # We are on sway
        return container.type == "floating_con"


async def set_splitting(i3, _, width: int) -> None:
    focused = (await i3.get_tree()).find_focused()
    if focused is None:
        return
    workspace = focused.workspace()
    tiled_windows = [leaf for leaf in workspace.leaves() if not is_floating(leaf)]
    if len(tiled_windows) == 1:
        await focused.command("splith")
    elif len(tiled_windows) == 2:
        left, right = tiled_windows
        await left.command("splitv")
        await right.command("splitv")
        await right.command(f"resize set width {width} ppt")


async def amain():
    parser = argparse.ArgumentParser(description="Stack layout for i3/sway wm.")
    parser.add_argument(
        "width",
        type=int,
        nargs="?",
        default=50,
        help="Optional width of second window in %%. Default: %(default)s",
    )
    args = parser.parse_args()
    width = min(max(args.width, 0), 100)
    i3 = await Connection(auto_reconnect=True).connect()
    i3.on(Event.WINDOW_NEW, partial(set_splitting, width=width))  # type: ignore
    i3.on(Event.WINDOW_CLOSE, partial(set_splitting, width=width))  # type: ignore
    await i3.main()


def main():
    asyncio.run(amain())



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['stacki3']

package_data = \
{'': ['*']}

install_requires = \
['i3ipc>=2.2.1,<3.0.0']

entry_points = \
{'console_scripts': ['stacki3 = stacki3:main']}

setup_kwargs = {
    'name': 'stacki3',
    'version': '1.0.0',
    'description': 'Stack layout for i3/sway wm.',
    'long_description': "# stacki3\n\nSimple stack layout for i3/sway wm.\n\n## How it works\n\nThe main idea is this - I only want max two columns on the screen.\nMore windows should be spawn vertically.\n\n![Preview](./preview.gif)\n\n(proportion set with `stacki3 45`)\n\n_stacki3_ does only 3 things:\n\n- when there is only **one** window set split to `horizontal`\n- when there are exactly **two** windows set split to `vertical` on both windows\n- _optionally_ when proportion is set with `width` argument (like in preview) resize the right window\n\nThat's it!\n\n## Instalation\n\n1. Install the package\n\n```bash\npip install --user stacki3\n```\n\n2. Inside your i3/sway config add\n\n```i3\n# Default with splitting 50:50\nexec stacki3\n# OR\n# Split first two windows 55:45\nexec stacki3 45\n```\n\n3. Log out and log back in\n\n## Inspiration\n\n[i3-master-stack](https://github.com/windwp/i3-master-stack)\n[autotiling](https://github.com/nwg-piotr/autotiling)\n",
    'author': 'Viliam Valent',
    'author_email': 'stacki3@viliamvalent.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/ViliamV/stacki3',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
